# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
from uuid import UUID
import typing



class AIModelError(IntEnum):
    NO_ERROR = 0
    ALREADY_EXISTS = 1
    NOT_FOUND = 2
    NOT_UPDATED = 3
    NOT_AUTHORIZED = 4
    AIMODEL_OUT_OF_CREDITS = 5
    AIMODEL_DONT_HANDLE_COMPLETION = 6




class AIModel(BaseModel):

    _one_of_dict = {"AIModel._enabled": {"fields": {"enabled"}}, "AIModel._id": {"fields": {"id"}}, "AIModel._image": {"fields": {"image"}}, "AIModel._name": {"fields": {"name"}}, "AIModel._name_alias": {"fields": {"name_alias"}}, "AIModel._provider": {"fields": {"provider"}}, "AIModel._restricted": {"fields": {"restricted"}}, "AIModel._type": {"fields": {"type"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 
    name: str = FieldInfo(default="") 
    provider: str = FieldInfo(default="") 
    image: str = FieldInfo(default="") 
    enabled: bool = FieldInfo(default=False) 
    type: str = FieldInfo(default="") 
    restricted: bool = FieldInfo(default=False) 
    name_alias: str = FieldInfo(default="") 




class CompletionResponse(BaseModel):

    _one_of_dict = {"CompletionResponse._image_resolution": {"fields": {"image_resolution"}}, "CompletionResponse._image_steps": {"fields": {"image_steps"}}, "CompletionResponse._input_tokens": {"fields": {"input_tokens"}}, "CompletionResponse._model_id": {"fields": {"model_id"}}, "CompletionResponse._output_tokens": {"fields": {"output_tokens"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    model_id: UUID = FieldInfo(default="") 
    completions: typing.List[str] = FieldInfo(default_factory=list) 
    input_tokens: int = FieldInfo(default=0) 
    output_tokens: int = FieldInfo(default=0) 
    image_resolution: str = FieldInfo(default="") 
    image_steps: int = FieldInfo(default=0) 




class AIModelResponseError(BaseModel):

    _one_of_dict = {"AIModelResponseError._code": {"fields": {"code"}}, "AIModelResponseError._message": {"fields": {"message"}}, "AIModelResponseError._reason": {"fields": {"reason"}}, "AIModelResponseError._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: AIModelError = FieldInfo(default=0) 
    status: str = FieldInfo(default="") 
    reason: str = FieldInfo(default="") 
    message: str = FieldInfo(default="") 




class AIModelListRequest(BaseModel):

    _one_of_dict = {"AIModelListRequest._page_number": {"fields": {"page_number"}}, "AIModelListRequest._page_size": {"fields": {"page_size"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    page_size: int = FieldInfo(default=0) 
    page_number: int = FieldInfo(default=0) 




class AIModelListResponse(BaseModel):

    _one_of_dict = {"AIModelListResponse._error": {"fields": {"error"}}, "AIModelListResponse._page_number": {"fields": {"page_number"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    aimodels: typing.List[AIModel] = FieldInfo(default_factory=list) 
    page_number: int = FieldInfo(default=0) 
    error: AIModelResponseError = FieldInfo() 




class AIModelGetRequest(BaseModel):

    _one_of_dict = {"AIModelGetRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 




class AIModelGetResponse(BaseModel):

    _one_of_dict = {"AIModelGetResponse._aimodel": {"fields": {"aimodel"}}, "AIModelGetResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    aimodel: AIModel = FieldInfo() 
    error: AIModelResponseError = FieldInfo() 




class AIModelCompletionRequest(BaseModel):

    _one_of_dict = {"AIModelCompletionRequest._id": {"fields": {"id"}}, "AIModelCompletionRequest._payload": {"fields": {"payload"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 
    payload: str = FieldInfo(default="") 




class AIModelCompletionResponse(BaseModel):

    _one_of_dict = {"AIModelCompletionResponse._completion": {"fields": {"completion"}}, "AIModelCompletionResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    completion: CompletionResponse = FieldInfo() 
    error: AIModelResponseError = FieldInfo() 




class AIModelAdminCreationRequest(BaseModel):

    _one_of_dict = {"AIModelAdminCreationRequest._enabled": {"fields": {"enabled"}}, "AIModelAdminCreationRequest._image": {"fields": {"image"}}, "AIModelAdminCreationRequest._name": {"fields": {"name"}}, "AIModelAdminCreationRequest._name_alias": {"fields": {"name_alias"}}, "AIModelAdminCreationRequest._provider": {"fields": {"provider"}}, "AIModelAdminCreationRequest._restricted": {"fields": {"restricted"}}, "AIModelAdminCreationRequest._type": {"fields": {"type"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    provider: str = FieldInfo(default="") 
    image: str = FieldInfo(default="") 
    enabled: bool = FieldInfo(default=False) 
    type: str = FieldInfo(default="") 
    restricted: bool = FieldInfo(default=False) 
    name_alias: str = FieldInfo(default="") 




class AIModelAdminCreationResponse(BaseModel):

    _one_of_dict = {"AIModelAdminCreationResponse._aimodel": {"fields": {"aimodel"}}, "AIModelAdminCreationResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    aimodel: AIModel = FieldInfo() 
    error: AIModelResponseError = FieldInfo() 




class AIModelAdminDeleteRequest(BaseModel):

    _one_of_dict = {"AIModelAdminDeleteRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 




class AIModelAdminDeleteResponse(BaseModel):

    _one_of_dict = {"AIModelAdminDeleteResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: AIModelResponseError = FieldInfo() 





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workspace.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fworkspace.proto\x12\tworkspace\x1a\x0evalidate.proto\"\x97\x02\n\tWorkspace\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\x17\n\ncreated_at\x18\x07 \x01(\tH\x06\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x0e\n\x0c_is_personalB\r\n\x0b_created_at\"\xa9\x01\n\x0fWorkspaceUpdate\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_color\"\xb8\x02\n\rWorkspaceUser\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12.\n\x04role\x18\x03 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x02\x88\x01\x01\x12\x35\n\x06status\x18\x04 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x03\x88\x01\x01\x12\x16\n\tcreate_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x16\n\tupdate_at\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x07\n\x05_roleB\t\n\x07_statusB\x0c\n\n_create_atB\x0c\n\n_update_at\"\x90\x01\n\x13WorkspaceUserUpdate\x12.\n\x04role\x18\x01 \x01(\tB\x1b\xfa\x42\x18r\x16R\x05ownerR\x05\x61\x64minR\x06memberH\x00\x88\x01\x01\x12\x35\n\x06status\x18\x02 \x01(\tB \xfa\x42\x1dr\x1bR\x06\x61\x63tiveR\x07invitedR\x08\x64\x65\x63linedH\x01\x88\x01\x01\x42\x07\n\x05_roleB\t\n\x07_status\"\xb1\x01\n\x0fWorkspacePlugin\x12\x19\n\x02id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x16\n\tcreate_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x05\n\x03_idB\x0f\n\r_workspace_idB\n\n\x08_payloadB\x0c\n\n_create_at\"9\n\x15WorkspacePluginUpdate\x12\x14\n\x07payload\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_payload\"q\n\x16WorkspaceResponseError\x12,\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x19.workspace.WorkspaceErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_codeB\n\n\x08_message\"B\n\x14WorkspaceListRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\n\n\x08_user_id\"\x82\x01\n\x15WorkspaceListResponse\x12(\n\nworkspaces\x18\x01 \x03(\x0b\x32\x14.workspace.Workspace\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x86\x02\n\x16WorkspaceCreateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04logo\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rprimary_color\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1c\n\x0fsecondary_color\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x18\n\x0bis_personal\x18\x06 \x01(\x08H\x05\x88\x01\x01\x42\n\n\x08_user_idB\x07\n\x05_nameB\x07\n\x05_logoB\x10\n\x0e_primary_colorB\x12\n\x10_secondary_colorB\x0e\n\x0c_is_personal\"\x96\x01\n\x17WorkspaceCreateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"w\n\x13WorkspaceGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\x93\x01\n\x14WorkspaceGetResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"\x90\x01\n\x16WorkspaceUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x32\n\tworkspace\x18\x02 \x01(\x0b\x32\x1a.workspace.WorkspaceUpdateH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_workspace\"\x96\x01\n\x17WorkspaceUpdateResponse\x12,\n\tworkspace\x18\x01 \x01(\x0b\x32\x14.workspace.WorkspaceH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x0c\n\n_workspaceB\x08\n\x06_error\"z\n\x16WorkspaceDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"Z\n\x17WorkspaceDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"P\n\x18WorkspaceUserListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x8f\x01\n\x19WorkspaceUserListResponse\x12\x31\n\x0fworkspace_users\x18\x01 \x03(\x0b\x32\x18.workspace.WorkspaceUser\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"{\n\x17WorkspaceUserGetRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"\xa5\x01\n\x18WorkspaceUserGetResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"\xce\x01\n\x1aWorkspaceUserUpdateRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12;\n\x0eworkspace_user\x18\x03 \x01(\x0b\x32\x1e.workspace.WorkspaceUserUpdateH\x02\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_idB\x11\n\x0f_workspace_user\"\xa8\x01\n\x1bWorkspaceUserUpdateResponse\x12\x35\n\x0eworkspace_user\x18\x01 \x01(\x0b\x32\x18.workspace.WorkspaceUserH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x11\n\x0f_workspace_userB\x08\n\x06_error\"~\n\x1aWorkspaceUserDeleteRequest\x12\x1e\n\x07user_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12#\n\x0cworkspace_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\n\n\x08_user_idB\x0f\n\r_workspace_id\"^\n\x1bWorkspaceUserDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"v\n\x1cWorkspacePluginCreateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12\x14\n\x07payload\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\n\n\x08_payload\"\xb0\x01\n\x1dWorkspacePluginCreateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x81\x01\n\x19WorkspacePluginGetRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"\xad\x01\n\x1aWorkspacePluginGetResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"R\n\x1aWorkspacePluginListRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x42\x0f\n\r_workspace_id\"\x95\x01\n\x1bWorkspacePluginListResponse\x12\x35\n\x11workspace_plugins\x18\x01 \x03(\x0b\x32\x1a.workspace.WorkspacePlugin\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xda\x01\n\x1cWorkspacePluginUpdateRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12?\n\x10workspace_plugin\x18\x03 \x01(\x0b\x32 .workspace.WorkspacePluginUpdateH\x02\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_idB\x13\n\x11_workspace_plugin\"\xb0\x01\n\x1dWorkspacePluginUpdateResponse\x12\x39\n\x10workspace_plugin\x18\x01 \x01(\x0b\x32\x1a.workspace.WorkspacePluginH\x00\x88\x01\x01\x12\x35\n\x05\x65rror\x18\x02 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x01\x88\x01\x01\x42\x13\n\x11_workspace_pluginB\x08\n\x06_error\"\x84\x01\n\x1cWorkspacePluginDeleteRequest\x12#\n\x0cworkspace_id\x18\x01 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x00\x88\x01\x01\x12 \n\tplugin_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x42\x0f\n\r_workspace_idB\x0c\n\n_plugin_id\"`\n\x1dWorkspacePluginDeleteResponse\x12\x35\n\x05\x65rror\x18\x01 \x01(\x0b\x32!.workspace.WorkspaceResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error*\x8b\x02\n\x0eWorkspaceError\x12\x16\n\x12WORKSPACE_NO_ERROR\x10\x00\x12\x17\n\x13WORKSPACE_NOT_FOUND\x10\x01\x12!\n\x1dWORKSPACE_USER_ALREADY_EXISTS\x10\x02\x12\x1c\n\x18WORKSPACE_USER_NOT_FOUND\x10\x03\x12!\n\x1dWORKSPACE_USER_ALREADY_ACTIVE\x10\x04\x12(\n$USER_ALREADY_HAVE_PERSONAL_WORKSPACE\x10\x05\x12\x1e\n\x1aWORKSPACE_PLUGIN_NOT_FOUND\x10\x06\x12\x1a\n\x15INTERNAL_SERVER_ERROR\x10\xe8\x07\x42\x32Z0github.com/jupyter-naas/naas-models/go/workspaceb\x06proto3')

_WORKSPACEERROR = DESCRIPTOR.enum_types_by_name['WorkspaceError']
WorkspaceError = enum_type_wrapper.EnumTypeWrapper(_WORKSPACEERROR)
WORKSPACE_NO_ERROR = 0
WORKSPACE_NOT_FOUND = 1
WORKSPACE_USER_ALREADY_EXISTS = 2
WORKSPACE_USER_NOT_FOUND = 3
WORKSPACE_USER_ALREADY_ACTIVE = 4
USER_ALREADY_HAVE_PERSONAL_WORKSPACE = 5
WORKSPACE_PLUGIN_NOT_FOUND = 6
INTERNAL_SERVER_ERROR = 1000


_WORKSPACE = DESCRIPTOR.message_types_by_name['Workspace']
_WORKSPACEUPDATE = DESCRIPTOR.message_types_by_name['WorkspaceUpdate']
_WORKSPACEUSER = DESCRIPTOR.message_types_by_name['WorkspaceUser']
_WORKSPACEUSERUPDATE = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdate']
_WORKSPACEPLUGIN = DESCRIPTOR.message_types_by_name['WorkspacePlugin']
_WORKSPACEPLUGINUPDATE = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdate']
_WORKSPACERESPONSEERROR = DESCRIPTOR.message_types_by_name['WorkspaceResponseError']
_WORKSPACELISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceListRequest']
_WORKSPACELISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceListResponse']
_WORKSPACECREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceCreateRequest']
_WORKSPACECREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceCreateResponse']
_WORKSPACEGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceGetRequest']
_WORKSPACEGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceGetResponse']
_WORKSPACEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUpdateRequest']
_WORKSPACEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUpdateResponse']
_WORKSPACEDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceDeleteRequest']
_WORKSPACEDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceDeleteResponse']
_WORKSPACEUSERLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserListRequest']
_WORKSPACEUSERLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserListResponse']
_WORKSPACEUSERGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserGetRequest']
_WORKSPACEUSERGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserGetResponse']
_WORKSPACEUSERUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdateRequest']
_WORKSPACEUSERUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserUpdateResponse']
_WORKSPACEUSERDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspaceUserDeleteRequest']
_WORKSPACEUSERDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspaceUserDeleteResponse']
_WORKSPACEPLUGINCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginCreateRequest']
_WORKSPACEPLUGINCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginCreateResponse']
_WORKSPACEPLUGINGETREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginGetRequest']
_WORKSPACEPLUGINGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginGetResponse']
_WORKSPACEPLUGINLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginListRequest']
_WORKSPACEPLUGINLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginListResponse']
_WORKSPACEPLUGINUPDATEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdateRequest']
_WORKSPACEPLUGINUPDATERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginUpdateResponse']
_WORKSPACEPLUGINDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkspacePluginDeleteRequest']
_WORKSPACEPLUGINDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkspacePluginDeleteResponse']
Workspace = _reflection.GeneratedProtocolMessageType('Workspace', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.Workspace)
  })
_sym_db.RegisterMessage(Workspace)

WorkspaceUpdate = _reflection.GeneratedProtocolMessageType('WorkspaceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdate)
  })
_sym_db.RegisterMessage(WorkspaceUpdate)

WorkspaceUser = _reflection.GeneratedProtocolMessageType('WorkspaceUser', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSER,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUser)
  })
_sym_db.RegisterMessage(WorkspaceUser)

WorkspaceUserUpdate = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdate)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdate)

WorkspacePlugin = _reflection.GeneratedProtocolMessageType('WorkspacePlugin', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGIN,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePlugin)
  })
_sym_db.RegisterMessage(WorkspacePlugin)

WorkspacePluginUpdate = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdate', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdate)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdate)

WorkspaceResponseError = _reflection.GeneratedProtocolMessageType('WorkspaceResponseError', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACERESPONSEERROR,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceResponseError)
  })
_sym_db.RegisterMessage(WorkspaceResponseError)

WorkspaceListRequest = _reflection.GeneratedProtocolMessageType('WorkspaceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACELISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceListRequest)
  })
_sym_db.RegisterMessage(WorkspaceListRequest)

WorkspaceListResponse = _reflection.GeneratedProtocolMessageType('WorkspaceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACELISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceListResponse)
  })
_sym_db.RegisterMessage(WorkspaceListResponse)

WorkspaceCreateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECREATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceCreateRequest)
  })
_sym_db.RegisterMessage(WorkspaceCreateRequest)

WorkspaceCreateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACECREATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceCreateResponse)
  })
_sym_db.RegisterMessage(WorkspaceCreateResponse)

WorkspaceGetRequest = _reflection.GeneratedProtocolMessageType('WorkspaceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceGetRequest)
  })
_sym_db.RegisterMessage(WorkspaceGetRequest)

WorkspaceGetResponse = _reflection.GeneratedProtocolMessageType('WorkspaceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceGetResponse)
  })
_sym_db.RegisterMessage(WorkspaceGetResponse)

WorkspaceUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspaceUpdateRequest)

WorkspaceUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspaceUpdateResponse)

WorkspaceDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspaceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspaceDeleteRequest)

WorkspaceDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspaceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspaceDeleteResponse)

WorkspaceUserListRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERLISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserListRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserListRequest)

WorkspaceUserListResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERLISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserListResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserListResponse)

WorkspaceUserGetRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserGetRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserGetRequest)

WorkspaceUserGetResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserGetResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserGetResponse)

WorkspaceUserUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdateRequest)

WorkspaceUserUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserUpdateResponse)

WorkspaceUserDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspaceUserDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspaceUserDeleteRequest)

WorkspaceUserDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspaceUserDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEUSERDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspaceUserDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspaceUserDeleteResponse)

WorkspacePluginCreateRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINCREATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginCreateRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginCreateRequest)

WorkspacePluginCreateResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINCREATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginCreateResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginCreateResponse)

WorkspacePluginGetRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINGETREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginGetRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginGetRequest)

WorkspacePluginGetResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINGETRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginGetResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginGetResponse)

WorkspacePluginListRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINLISTREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginListRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginListRequest)

WorkspacePluginListResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINLISTRESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginListResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginListResponse)

WorkspacePluginUpdateRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdateRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdateRequest)

WorkspacePluginUpdateResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINUPDATERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginUpdateResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginUpdateResponse)

WorkspacePluginDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkspacePluginDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINDELETEREQUEST,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginDeleteRequest)
  })
_sym_db.RegisterMessage(WorkspacePluginDeleteRequest)

WorkspacePluginDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkspacePluginDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKSPACEPLUGINDELETERESPONSE,
  '__module__' : 'workspace_pb2'
  # @@protoc_insertion_point(class_scope:workspace.WorkspacePluginDeleteResponse)
  })
_sym_db.RegisterMessage(WorkspacePluginDeleteResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z0github.com/jupyter-naas/naas-models/go/workspace'
  _WORKSPACE.fields_by_name['id']._options = None
  _WORKSPACE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['user_id']._options = None
  _WORKSPACEUSER.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSER.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSER.fields_by_name['role']._options = None
  _WORKSPACEUSER.fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _WORKSPACEUSER.fields_by_name['status']._options = None
  _WORKSPACEUSER.fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _WORKSPACEUSERUPDATE.fields_by_name['role']._options = None
  _WORKSPACEUSERUPDATE.fields_by_name['role']._serialized_options = b'\372B\030r\026R\005ownerR\005adminR\006member'
  _WORKSPACEUSERUPDATE.fields_by_name['status']._options = None
  _WORKSPACEUSERUPDATE.fields_by_name['status']._serialized_options = b'\372B\035r\033R\006activeR\007invitedR\010declined'
  _WORKSPACEPLUGIN.fields_by_name['id']._options = None
  _WORKSPACEPLUGIN.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGIN.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGIN.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACELISTREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACELISTREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACECREATEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACECREATEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEGETREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEGETREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEDELETEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEDELETEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERLISTREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERLISTREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERGETREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERGETREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['user_id']._options = None
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEUSERDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINCREATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINCREATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINGETREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINLISTREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINLISTREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINUPDATEREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['workspace_id']._options = None
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['workspace_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['plugin_id']._options = None
  _WORKSPACEPLUGINDELETEREQUEST.fields_by_name['plugin_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _WORKSPACEERROR._serialized_start=5324
  _WORKSPACEERROR._serialized_end=5591
  _WORKSPACE._serialized_start=47
  _WORKSPACE._serialized_end=326
  _WORKSPACEUPDATE._serialized_start=329
  _WORKSPACEUPDATE._serialized_end=498
  _WORKSPACEUSER._serialized_start=501
  _WORKSPACEUSER._serialized_end=813
  _WORKSPACEUSERUPDATE._serialized_start=816
  _WORKSPACEUSERUPDATE._serialized_end=960
  _WORKSPACEPLUGIN._serialized_start=963
  _WORKSPACEPLUGIN._serialized_end=1140
  _WORKSPACEPLUGINUPDATE._serialized_start=1142
  _WORKSPACEPLUGINUPDATE._serialized_end=1199
  _WORKSPACERESPONSEERROR._serialized_start=1201
  _WORKSPACERESPONSEERROR._serialized_end=1314
  _WORKSPACELISTREQUEST._serialized_start=1316
  _WORKSPACELISTREQUEST._serialized_end=1382
  _WORKSPACELISTRESPONSE._serialized_start=1385
  _WORKSPACELISTRESPONSE._serialized_end=1515
  _WORKSPACECREATEREQUEST._serialized_start=1518
  _WORKSPACECREATEREQUEST._serialized_end=1780
  _WORKSPACECREATERESPONSE._serialized_start=1783
  _WORKSPACECREATERESPONSE._serialized_end=1933
  _WORKSPACEGETREQUEST._serialized_start=1935
  _WORKSPACEGETREQUEST._serialized_end=2054
  _WORKSPACEGETRESPONSE._serialized_start=2057
  _WORKSPACEGETRESPONSE._serialized_end=2204
  _WORKSPACEUPDATEREQUEST._serialized_start=2207
  _WORKSPACEUPDATEREQUEST._serialized_end=2351
  _WORKSPACEUPDATERESPONSE._serialized_start=2354
  _WORKSPACEUPDATERESPONSE._serialized_end=2504
  _WORKSPACEDELETEREQUEST._serialized_start=2506
  _WORKSPACEDELETEREQUEST._serialized_end=2628
  _WORKSPACEDELETERESPONSE._serialized_start=2630
  _WORKSPACEDELETERESPONSE._serialized_end=2720
  _WORKSPACEUSERLISTREQUEST._serialized_start=2722
  _WORKSPACEUSERLISTREQUEST._serialized_end=2802
  _WORKSPACEUSERLISTRESPONSE._serialized_start=2805
  _WORKSPACEUSERLISTRESPONSE._serialized_end=2948
  _WORKSPACEUSERGETREQUEST._serialized_start=2950
  _WORKSPACEUSERGETREQUEST._serialized_end=3073
  _WORKSPACEUSERGETRESPONSE._serialized_start=3076
  _WORKSPACEUSERGETRESPONSE._serialized_end=3241
  _WORKSPACEUSERUPDATEREQUEST._serialized_start=3244
  _WORKSPACEUSERUPDATEREQUEST._serialized_end=3450
  _WORKSPACEUSERUPDATERESPONSE._serialized_start=3453
  _WORKSPACEUSERUPDATERESPONSE._serialized_end=3621
  _WORKSPACEUSERDELETEREQUEST._serialized_start=3623
  _WORKSPACEUSERDELETEREQUEST._serialized_end=3749
  _WORKSPACEUSERDELETERESPONSE._serialized_start=3751
  _WORKSPACEUSERDELETERESPONSE._serialized_end=3845
  _WORKSPACEPLUGINCREATEREQUEST._serialized_start=3847
  _WORKSPACEPLUGINCREATEREQUEST._serialized_end=3965
  _WORKSPACEPLUGINCREATERESPONSE._serialized_start=3968
  _WORKSPACEPLUGINCREATERESPONSE._serialized_end=4144
  _WORKSPACEPLUGINGETREQUEST._serialized_start=4147
  _WORKSPACEPLUGINGETREQUEST._serialized_end=4276
  _WORKSPACEPLUGINGETRESPONSE._serialized_start=4279
  _WORKSPACEPLUGINGETRESPONSE._serialized_end=4452
  _WORKSPACEPLUGINLISTREQUEST._serialized_start=4454
  _WORKSPACEPLUGINLISTREQUEST._serialized_end=4536
  _WORKSPACEPLUGINLISTRESPONSE._serialized_start=4539
  _WORKSPACEPLUGINLISTRESPONSE._serialized_end=4688
  _WORKSPACEPLUGINUPDATEREQUEST._serialized_start=4691
  _WORKSPACEPLUGINUPDATEREQUEST._serialized_end=4909
  _WORKSPACEPLUGINUPDATERESPONSE._serialized_start=4912
  _WORKSPACEPLUGINUPDATERESPONSE._serialized_end=5088
  _WORKSPACEPLUGINDELETEREQUEST._serialized_start=5091
  _WORKSPACEPLUGINDELETEREQUEST._serialized_end=5223
  _WORKSPACEPLUGINDELETERESPONSE._serialized_start=5225
  _WORKSPACEPLUGINDELETERESPONSE._serialized_end=5321
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from naas_models.pydantic.common_p2p import FieldMask
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
import typing



class MessageType(IntEnum):
    UNDEFINED = 0
    SYSTEM = 1
    AI = 2
    HUMAN = 3


class MessageError(IntEnum):
    MESSAGE_NO_ERROR = 0
    MESSAGE_ALREADY_EXISTS = 1
    MESSAGE_NOT_FOUND = 2
    MESSAGE_NOT_UPDATED = 3
    MESSAGE_NOT_AUTHORIZED = 4
    MESSAGE_INTERNAL_SERVER_ERROR = 1000


class CompletionStatus(IntEnum):
    COMPLETED = 0
    FAILED = 1
    TIMEOUT = 2


class ChatError(IntEnum):
    CHAT_NO_ERROR = 0
    CHAT_ALREADY_EXISTS = 1
    CHAT_NOT_FOUND = 2
    CHAT_NOT_UPDATED = 3
    CHAT_NOT_AUTHORIZED = 4
    CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXISTS = 5
    CHAT_AIMODEL_NOT_FOUND = 6
    CHAT_OUT_OF_CREDIT = 7
    CHAT_CONTEXT_LENGTH_EXCEEDED = 8
    CHAT_INTERNAL_SERVER_ERROR = 1000




class MessageResponseError(BaseModel):

    _one_of_dict = {"MessageResponseError._code": {"fields": {"code"}}, "MessageResponseError._message": {"fields": {"message"}}, "MessageResponseError._reason": {"fields": {"reason"}}, "MessageResponseError._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: MessageError = FieldInfo(default=0) 
    status: str = FieldInfo(default="") 
    reason: str = FieldInfo(default="") 
    message: str = FieldInfo(default="") 




class Message(BaseModel):

    _one_of_dict = {"Message._archived_at": {"fields": {"archived_at"}}, "Message._chat_id": {"fields": {"chat_id"}}, "Message._created_at": {"fields": {"created_at"}}, "Message._deleted_at": {"fields": {"deleted_at"}}, "Message._from_user": {"fields": {"from_user"}}, "Message._id": {"fields": {"id"}}, "Message._message": {"fields": {"message"}}, "Message._message_language": {"fields": {"message_language"}}, "Message._message_type": {"fields": {"message_type"}}, "Message._metadata": {"fields": {"metadata"}}, "Message._model_id": {"fields": {"model_id"}}, "Message._selected": {"fields": {"selected"}}, "Message._type": {"fields": {"type"}}, "Message._version": {"fields": {"version"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    version: int = FieldInfo(default=0) 
    created_at: str = FieldInfo(default="") 
    chat_id: int = FieldInfo(default=0) 
    from_user: bool = FieldInfo(default=False) 
    message: str = FieldInfo(default="") 
    message_type: str = FieldInfo(default="") 
    message_language: str = FieldInfo(default="") 
    model_id: str = FieldInfo(default="") 
    type: MessageType = FieldInfo(default=0) 
    metadata: str = FieldInfo(default="") 
    deleted_at: str = FieldInfo(default="") 
    selected: bool = FieldInfo(default=False) 
    archived_at: str = FieldInfo(default="") 




class MessageUpdate(BaseModel):

    _one_of_dict = {"MessageUpdate._archived_at": {"fields": {"archived_at"}}, "MessageUpdate._field_mask": {"fields": {"field_mask"}}, "MessageUpdate._message": {"fields": {"message"}}, "MessageUpdate._message_language": {"fields": {"message_language"}}, "MessageUpdate._message_type": {"fields": {"message_type"}}, "MessageUpdate._metadata": {"fields": {"metadata"}}, "MessageUpdate._selected": {"fields": {"selected"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    message: str = FieldInfo(default="") 
    message_type: str = FieldInfo(default="") 
    message_language: str = FieldInfo(default="") 
    metadata: str = FieldInfo(default="") 
    selected: bool = FieldInfo(default=False) 
    archived_at: str = FieldInfo(default="") 
    field_mask: FieldMask = FieldInfo() 




class Messages(BaseModel):

    messages: typing.List[Message] = FieldInfo(default_factory=list) 




class MessageDeletionRequest(BaseModel):

    _one_of_dict = {"MessageDeletionRequest._id": {"fields": {"id"}}, "MessageDeletionRequest._version": {"fields": {"version"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    version: int = FieldInfo(default=0) 




class MessageDeletionResponse(BaseModel):

    _one_of_dict = {"MessageDeletionResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: MessageError = FieldInfo(default=0) 




class MessageRatinResponseError(BaseModel):

    _one_of_dict = {"MessageRatinResponseError._code": {"fields": {"code"}}, "MessageRatinResponseError._message": {"fields": {"message"}}, "MessageRatinResponseError._reason": {"fields": {"reason"}}, "MessageRatinResponseError._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: MessageError = FieldInfo(default=0) 
    status: str = FieldInfo(default="") 
    reason: str = FieldInfo(default="") 
    message: str = FieldInfo(default="") 




class MessageRating(BaseModel):

    _one_of_dict = {"MessageRating._created_at": {"fields": {"created_at"}}, "MessageRating._message_id": {"fields": {"message_id"}}, "MessageRating._message_version": {"fields": {"message_version"}}, "MessageRating._rating": {"fields": {"rating"}}, "MessageRating._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    message_id: int = FieldInfo(default=0) 
    user_id: str = FieldInfo(default="") 
    message_version: int = FieldInfo(default=0) 
    created_at: str = FieldInfo(default="") 
    rating: str = FieldInfo(default="", regex="^(LIKE|DISLIKE)$") 




class MessageRatingCreationRequest(BaseModel):

    _one_of_dict = {"MessageRatingCreationRequest._message_id": {"fields": {"message_id"}}, "MessageRatingCreationRequest._message_version": {"fields": {"message_version"}}, "MessageRatingCreationRequest._rating": {"fields": {"rating"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    message_id: int = FieldInfo(default=0) 
    message_version: int = FieldInfo(default=0) 
    rating: str = FieldInfo(default="", regex="^(LIKE|DISLIKE)$") 




class MessageRatingCreationResponse(BaseModel):

    _one_of_dict = {"MessageRatingCreationResponse._error": {"fields": {"error"}}, "MessageRatingCreationResponse._message_rating": {"fields": {"message_rating"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: MessageRatinResponseError = FieldInfo() 
    message_rating: MessageRating = FieldInfo() 




class Chat(BaseModel):

    _one_of_dict = {"Chat._created_at": {"fields": {"created_at"}}, "Chat._deleted_at": {"fields": {"deleted_at"}}, "Chat._id": {"fields": {"id"}}, "Chat._is_group": {"fields": {"is_group"}}, "Chat._is_personal_assistant": {"fields": {"is_personal_assistant"}}, "Chat._name": {"fields": {"name"}}, "Chat._starred_at": {"fields": {"starred_at"}}, "Chat._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    created_at: str = FieldInfo(default="") 
    user_id: str = FieldInfo(default="") 
    name: str = FieldInfo(default="") 
    deleted_at: str = FieldInfo(default="") 
    is_group: bool = FieldInfo(default=False) 
    is_personal_assistant: bool = FieldInfo(default=False) 
    starred_at: str = FieldInfo(default="") 




class ChatUpdate(BaseModel):

    _one_of_dict = {"ChatUpdate._field_mask": {"fields": {"field_mask"}}, "ChatUpdate._is_group": {"fields": {"is_group"}}, "ChatUpdate._is_personal_assistant": {"fields": {"is_personal_assistant"}}, "ChatUpdate._name": {"fields": {"name"}}, "ChatUpdate._starred_at": {"fields": {"starred_at"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    is_group: bool = FieldInfo(default=False) 
    is_personal_assistant: bool = FieldInfo(default=False) 
    starred_at: str = FieldInfo(default="") 
    field_mask: FieldMask = FieldInfo() 




class ChatMessages(BaseModel):

    messages: typing.Dict[int, Messages] = FieldInfo(default_factory=dict) 




class ChatResponseError(BaseModel):

    _one_of_dict = {"ChatResponseError._code": {"fields": {"code"}}, "ChatResponseError._message": {"fields": {"message"}}, "ChatResponseError._reason": {"fields": {"reason"}}, "ChatResponseError._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: ChatError = FieldInfo(default=0) 
    status: str = FieldInfo(default="") 
    reason: str = FieldInfo(default="") 
    message: str = FieldInfo(default="") 




class ChatCreationRequest(BaseModel):

    _one_of_dict = {"ChatCreationRequest._is_personal_assistant": {"fields": {"is_personal_assistant"}}, "ChatCreationRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    is_personal_assistant: bool = FieldInfo(default=False) 




class ChatCreationResponse(BaseModel):

    _one_of_dict = {"ChatCreationResponse._chat": {"fields": {"chat"}}, "ChatCreationResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    chat: Chat = FieldInfo() 
    error: ChatResponseError = FieldInfo() 




class ChatGetRequest(BaseModel):

    _one_of_dict = {"ChatGetRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 




class ChatGetResponse(BaseModel):

    _one_of_dict = {"ChatGetResponse._chat": {"fields": {"chat"}}, "ChatGetResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    chat: Chat = FieldInfo() 
    error: ChatResponseError = FieldInfo() 




class ChatMessageGetRequest(BaseModel):

    _one_of_dict = {"ChatMessageGetRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 




class ChatMessageGetResponse(BaseModel):

    _one_of_dict = {"ChatMessageGetResponse._error": {"fields": {"error"}}, "ChatMessageGetResponse._messages": {"fields": {"messages"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: ChatResponseError = FieldInfo() 
    messages: ChatMessages = FieldInfo() 




class ChatDeletionRequest(BaseModel):

    _one_of_dict = {"ChatDeletionRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 




class ChatDeletionResponse(BaseModel):

    _one_of_dict = {"ChatDeletionResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: ChatResponseError = FieldInfo() 




class ChatUpdateRequest(BaseModel):

    _one_of_dict = {"ChatUpdateRequest._chat_update": {"fields": {"chat_update"}}, "ChatUpdateRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    chat_update: ChatUpdate = FieldInfo() 




class ChatUpdateResponse(BaseModel):

    _one_of_dict = {"ChatUpdateResponse._chat": {"fields": {"chat"}}, "ChatUpdateResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    chat: Chat = FieldInfo() 
    error: ChatResponseError = FieldInfo() 




class ChatListRequest(BaseModel):

    _one_of_dict = {"ChatListRequest._page_number": {"fields": {"page_number"}}, "ChatListRequest._page_size": {"fields": {"page_size"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    page_size: int = FieldInfo(default=0) 
    page_number: int = FieldInfo(default=0) 




class ChatListResponse(BaseModel):

    _one_of_dict = {"ChatListResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    chat: typing.List[Chat] = FieldInfo(default_factory=list) 
    error: ChatResponseError = FieldInfo() 




class ChatStarRequest(BaseModel):

    _one_of_dict = {"ChatStarRequest._id": {"fields": {"id"}}, "ChatStarRequest._star": {"fields": {"star"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    star: bool = FieldInfo(default=False) 




class ChatStarResponse(BaseModel):

    _one_of_dict = {"ChatStarResponse._chat": {"fields": {"chat"}}, "ChatStarResponse._code": {"fields": {"code"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    chat: Chat = FieldInfo() 
    code: ChatError = FieldInfo(default=0) 




class ChatArchiveRequest(BaseModel):

    _one_of_dict = {"ChatArchiveRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 




class ChatArchiveResponse(BaseModel):

    _one_of_dict = {"ChatArchiveResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: ChatResponseError = FieldInfo() 




class CompletionResponse(BaseModel):

    _one_of_dict = {"CompletionResponse._image_resolution": {"fields": {"image_resolution"}}, "CompletionResponse._image_steps": {"fields": {"image_steps"}}, "CompletionResponse._input_tokens": {"fields": {"input_tokens"}}, "CompletionResponse._output_tokens": {"fields": {"output_tokens"}}, "CompletionResponse._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    messages: typing.List[Message] = FieldInfo(default_factory=list) 
    input_tokens: int = FieldInfo(default=0) 
    output_tokens: int = FieldInfo(default=0) 
    image_resolution: str = FieldInfo(default="") 
    image_steps: int = FieldInfo(default=0) 
    status: CompletionStatus = FieldInfo(default=0) 




class BasePayload(BaseModel):

    _one_of_dict = {"BasePayload._name": {"fields": {"name"}}, "BasePayload._prompt": {"fields": {"prompt"}}, "BasePayload._url": {"fields": {"url"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    url: str = FieldInfo(default="") 
    prompt: str = FieldInfo(default="") 




class ChatCompletionRequest(BaseModel):

    _one_of_dict = {"ChatCompletionRequest._id": {"fields": {"id"}}, "ChatCompletionRequest._model_id": {"fields": {"model_id"}}, "ChatCompletionRequest._payload": {"fields": {"payload"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 
    model_id: str = FieldInfo(default="") 
    payload: str = FieldInfo(default="") 




class ChatStopCompletionRequest(BaseModel):

    _one_of_dict = {"ChatStopCompletionRequest._id": {"fields": {"id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: int = FieldInfo(default=0) 




class ChatStopCompletionResponse(BaseModel):

    _one_of_dict = {"ChatStopCompletionResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: ChatResponseError = FieldInfo() 




class ChatCompletionResponse(BaseModel):

    _one_of_dict = {"ChatCompletionResponse._completion": {"fields": {"completion"}}, "ChatCompletionResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    completion: CompletionResponse = FieldInfo() 
    error: ChatResponseError = FieldInfo() 





# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from protobuf_to_pydantic.get_desc.from_pb_option.types import UriRefStr
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
from uuid import UUID
import typing



class SpaceError(IntEnum):
    SPACE_NO_ERROR = 0
    SPACE_ALREADY_EXISTS = 1
    SPACE_NOT_FOUND = 2
    SPACE_NOT_UPDATED = 3
    SPACE_MUST_HAVE_ONE_CONTAINER_PORT = 4




class Container(BaseModel):

    _one_of_dict = {"Container._cpu": {"fields": {"cpu"}}, "Container._image": {"fields": {"image"}}, "Container._memory": {"fields": {"memory"}}, "Container._name": {"fields": {"name"}}, "Container._port": {"fields": {"port"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9-]+)$") 
    image: str = FieldInfo(default="", min_length=1, regex="^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$") 
    env: typing.Dict[str, str] = FieldInfo(default_factory=dict) 
    port: int = FieldInfo(default=0, ge=0, le=65535) 
    cpu: str = FieldInfo(default="", regex="^[0-9]+(.[0-9]+)?[m]?$") 
    memory: str = FieldInfo(default="", regex="^[0-9]+(Mi|Gi|Ki)$") 




class ContainerUpdate(BaseModel):

    _one_of_dict = {"ContainerUpdate._cpu": {"fields": {"cpu"}}, "ContainerUpdate._image": {"fields": {"image"}}, "ContainerUpdate._memory": {"fields": {"memory"}}, "ContainerUpdate._name": {"fields": {"name"}}, "ContainerUpdate._port": {"fields": {"port"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9-]+)$") 
    image: str = FieldInfo(default="", min_length=1, regex="^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$") 
    env: typing.Dict[str, str] = FieldInfo(default_factory=dict) 
    port: int = FieldInfo(default=0, ge=0, le=65535) 
    cpu: str = FieldInfo(default="", regex="^[0-9]+(.[0-9]+)?[m]?$") 
    memory: str = FieldInfo(default="", regex="^[0-9]+(Mi|Gi|Ki)$") 




class Space(BaseModel):

    _one_of_dict = {"Space._domain": {"fields": {"domain"}}, "Space._id": {"fields": {"id"}}, "Space._name": {"fields": {"name"}}, "Space._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    user_id: UUID = FieldInfo(default="") 
    id: UUID = FieldInfo(default="") 
    domain: UriRefStr = FieldInfo(default="") 
    containers: typing.List[Container] = FieldInfo(default_factory=list, min_items=1) 




class SpaceUpdate(BaseModel):

    _one_of_dict = {"SpaceUpdate._domain": {"fields": {"domain"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    domain: UriRefStr = FieldInfo(default="") 
    containers: typing.List[ContainerUpdate] = FieldInfo(default_factory=list, min_items=1) 




class SpaceResponseError(BaseModel):

    _one_of_dict = {"SpaceResponseError._code": {"fields": {"code"}}, "SpaceResponseError._message": {"fields": {"message"}}, "SpaceResponseError._reason": {"fields": {"reason"}}, "SpaceResponseError._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: SpaceError = FieldInfo(default=0) 
    status: str = FieldInfo(default="") 
    reason: str = FieldInfo(default="") 
    message: str = FieldInfo(default="") 




class SpaceCreationRequest(BaseModel):

    _one_of_dict = {"SpaceCreationRequest._domain": {"fields": {"domain"}}, "SpaceCreationRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    domain: UriRefStr = FieldInfo(default="") 
    containers: typing.List[Container] = FieldInfo(default_factory=list, min_items=1) 




class SpaceCreationResponse(BaseModel):

    _one_of_dict = {"SpaceCreationResponse._space": {"fields": {"space"}}, "SpaceCreationResponse._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    space: Space = FieldInfo() 
    status: str = FieldInfo(default="") 




class SpaceGetRequest(BaseModel):

    _one_of_dict = {"SpaceGetRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 




class SpaceGetResponse(BaseModel):

    _one_of_dict = {"SpaceGetResponse._space": {"fields": {"space"}}, "SpaceGetResponse._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    space: Space = FieldInfo() 
    status: str = FieldInfo(default="") 




class SpaceDeletionRequest(BaseModel):

    _one_of_dict = {"SpaceDeletionRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 




class SpaceDeletionResponse(BaseModel):

    _one_of_dict = {"SpaceDeletionResponse._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    status: str = FieldInfo(default="") 




class SpaceListRequest(BaseModel):

    _one_of_dict = {"SpaceListRequest._page_number": {"fields": {"page_number"}}, "SpaceListRequest._page_size": {"fields": {"page_size"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    page_size: int = FieldInfo(default=0) 
    page_number: int = FieldInfo(default=0) 




class SpaceListResponse(BaseModel):

    spaces: typing.List[Space] = FieldInfo(default_factory=list) 




class SpaceUpdateRequest(BaseModel):

    _one_of_dict = {"SpaceUpdateRequest._name": {"fields": {"name"}}, "SpaceUpdateRequest._space": {"fields": {"space"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="", min_length=1, max_length=63, regex="^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$") 
    space: SpaceUpdate = FieldInfo() 




class SpaceUpdateResponse(BaseModel):

    _one_of_dict = {"SpaceUpdateResponse._space": {"fields": {"space"}}, "SpaceUpdateResponse._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    space: Space = FieldInfo() 
    status: str = FieldInfo(default="") 





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: space.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bspace.proto\x12\x05space\x1a\x0evalidate.proto\"\x92\x03\n\tContainer\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12J\n\x05image\x18\x02 \x01(\tB6\xfa\x42\x33r1\x10\x01\x32*^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12&\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x19.space.Container.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[0-9]+(.[0-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[0-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\x9e\x03\n\x0f\x43ontainerUpdate\x12/\n\x04name\x18\x01 \x01(\tB\x1c\xfa\x42\x19r\x17\x10\x01\x18?2\x11^([A-Za-z0-9-]+)$H\x00\x88\x01\x01\x12J\n\x05image\x18\x02 \x01(\tB6\xfa\x42\x33r1\x10\x01\x32*^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$\xd0\x01\x00H\x01\x88\x01\x01\x12,\n\x03\x65nv\x18\x03 \x03(\x0b\x32\x1f.space.ContainerUpdate.EnvEntry\x12\x1e\n\x04port\x18\x04 \x01(\x03\x42\x0b\xfa\x42\x08\"\x06\x18\xff\xff\x03(\x00H\x02\x88\x01\x01\x12\x32\n\x03\x63pu\x18\x05 \x01(\tB \xfa\x42\x1dr\x1b\x32\x16^[0-9]+(.[0-9]+)?[m]?$\xd0\x01\x00H\x03\x88\x01\x01\x12\x31\n\x06memory\x18\x06 \x01(\tB\x1c\xfa\x42\x19r\x17\x32\x12^[0-9]+(Mi|Gi|Ki)$\xd0\x01\x00H\x04\x88\x01\x01\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_nameB\x08\n\x06_imageB\x07\n\x05_portB\x06\n\x04_cpuB\t\n\x07_memory\"\xf8\x01\n\x05Space\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1e\n\x07user_id\x18\x02 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x01\x88\x01\x01\x12\x19\n\x02id\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xb0\x01\x01H\x02\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x03\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x05\n\x03_idB\t\n\x07_domain\"m\n\x0bSpaceUpdate\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x00\x88\x01\x01\x12\x34\n\ncontainers\x18\x05 \x03(\x0b\x32\x16.space.ContainerUpdateB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\t\n\x07_domain\"\xa5\x01\n\x12SpaceResponseError\x12$\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x11.space.SpaceErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xb9\x01\n\x14SpaceCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x1d\n\x06\x64omain\x18\x04 \x01(\tB\x08\xfa\x42\x05r\x03\x90\x01\x01H\x01\x88\x01\x01\x12.\n\ncontainers\x18\x05 \x03(\x0b\x32\x10.space.ContainerB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x42\x07\n\x05_nameB\t\n\x07_domain\"c\n\x15SpaceCreationResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"Z\n\x0fSpaceGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"^\n\x10SpaceGetResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status\"_\n\x14SpaceDeletionRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"7\n\x15SpaceDeletionResponse\x12\x13\n\x06status\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_status\"b\n\x10SpaceListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"1\n\x11SpaceListResponse\x12\x1c\n\x06spaces\x18\x01 \x03(\x0b\x32\x0c.space.Space\"\x8f\x01\n\x12SpaceUpdateRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12&\n\x05space\x18\x02 \x01(\x0b\x32\x12.space.SpaceUpdateH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_space\"a\n\x13SpaceUpdateResponse\x12 \n\x05space\x18\x01 \x01(\x0b\x32\x0c.space.SpaceH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_spaceB\t\n\x07_status*\x8e\x01\n\nSpaceError\x12\x12\n\x0eSPACE_NO_ERROR\x10\x00\x12\x18\n\x14SPACE_ALREADY_EXISTS\x10\x01\x12\x13\n\x0fSPACE_NOT_FOUND\x10\x02\x12\x15\n\x11SPACE_NOT_UPDATED\x10\x03\x12&\n\"SPACE_MUST_HAVE_ONE_CONTAINER_PORT\x10\x04\x42.Z,github.com/jupyter-naas/naas-models/go/spaceb\x06proto3')

_SPACEERROR = DESCRIPTOR.enum_types_by_name['SpaceError']
SpaceError = enum_type_wrapper.EnumTypeWrapper(_SPACEERROR)
SPACE_NO_ERROR = 0
SPACE_ALREADY_EXISTS = 1
SPACE_NOT_FOUND = 2
SPACE_NOT_UPDATED = 3
SPACE_MUST_HAVE_ONE_CONTAINER_PORT = 4


_CONTAINER = DESCRIPTOR.message_types_by_name['Container']
_CONTAINER_ENVENTRY = _CONTAINER.nested_types_by_name['EnvEntry']
_CONTAINERUPDATE = DESCRIPTOR.message_types_by_name['ContainerUpdate']
_CONTAINERUPDATE_ENVENTRY = _CONTAINERUPDATE.nested_types_by_name['EnvEntry']
_SPACE = DESCRIPTOR.message_types_by_name['Space']
_SPACEUPDATE = DESCRIPTOR.message_types_by_name['SpaceUpdate']
_SPACERESPONSEERROR = DESCRIPTOR.message_types_by_name['SpaceResponseError']
_SPACECREATIONREQUEST = DESCRIPTOR.message_types_by_name['SpaceCreationRequest']
_SPACECREATIONRESPONSE = DESCRIPTOR.message_types_by_name['SpaceCreationResponse']
_SPACEGETREQUEST = DESCRIPTOR.message_types_by_name['SpaceGetRequest']
_SPACEGETRESPONSE = DESCRIPTOR.message_types_by_name['SpaceGetResponse']
_SPACEDELETIONREQUEST = DESCRIPTOR.message_types_by_name['SpaceDeletionRequest']
_SPACEDELETIONRESPONSE = DESCRIPTOR.message_types_by_name['SpaceDeletionResponse']
_SPACELISTREQUEST = DESCRIPTOR.message_types_by_name['SpaceListRequest']
_SPACELISTRESPONSE = DESCRIPTOR.message_types_by_name['SpaceListResponse']
_SPACEUPDATEREQUEST = DESCRIPTOR.message_types_by_name['SpaceUpdateRequest']
_SPACEUPDATERESPONSE = DESCRIPTOR.message_types_by_name['SpaceUpdateResponse']
Container = _reflection.GeneratedProtocolMessageType('Container', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINER_ENVENTRY,
    '__module__' : 'space_pb2'
    # @@protoc_insertion_point(class_scope:space.Container.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINER,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.Container)
  })
_sym_db.RegisterMessage(Container)
_sym_db.RegisterMessage(Container.EnvEntry)

ContainerUpdate = _reflection.GeneratedProtocolMessageType('ContainerUpdate', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONTAINERUPDATE_ENVENTRY,
    '__module__' : 'space_pb2'
    # @@protoc_insertion_point(class_scope:space.ContainerUpdate.EnvEntry)
    })
  ,
  'DESCRIPTOR' : _CONTAINERUPDATE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.ContainerUpdate)
  })
_sym_db.RegisterMessage(ContainerUpdate)
_sym_db.RegisterMessage(ContainerUpdate.EnvEntry)

Space = _reflection.GeneratedProtocolMessageType('Space', (_message.Message,), {
  'DESCRIPTOR' : _SPACE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.Space)
  })
_sym_db.RegisterMessage(Space)

SpaceUpdate = _reflection.GeneratedProtocolMessageType('SpaceUpdate', (_message.Message,), {
  'DESCRIPTOR' : _SPACEUPDATE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceUpdate)
  })
_sym_db.RegisterMessage(SpaceUpdate)

SpaceResponseError = _reflection.GeneratedProtocolMessageType('SpaceResponseError', (_message.Message,), {
  'DESCRIPTOR' : _SPACERESPONSEERROR,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceResponseError)
  })
_sym_db.RegisterMessage(SpaceResponseError)

SpaceCreationRequest = _reflection.GeneratedProtocolMessageType('SpaceCreationRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPACECREATIONREQUEST,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceCreationRequest)
  })
_sym_db.RegisterMessage(SpaceCreationRequest)

SpaceCreationResponse = _reflection.GeneratedProtocolMessageType('SpaceCreationResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPACECREATIONRESPONSE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceCreationResponse)
  })
_sym_db.RegisterMessage(SpaceCreationResponse)

SpaceGetRequest = _reflection.GeneratedProtocolMessageType('SpaceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPACEGETREQUEST,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceGetRequest)
  })
_sym_db.RegisterMessage(SpaceGetRequest)

SpaceGetResponse = _reflection.GeneratedProtocolMessageType('SpaceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPACEGETRESPONSE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceGetResponse)
  })
_sym_db.RegisterMessage(SpaceGetResponse)

SpaceDeletionRequest = _reflection.GeneratedProtocolMessageType('SpaceDeletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPACEDELETIONREQUEST,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceDeletionRequest)
  })
_sym_db.RegisterMessage(SpaceDeletionRequest)

SpaceDeletionResponse = _reflection.GeneratedProtocolMessageType('SpaceDeletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPACEDELETIONRESPONSE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceDeletionResponse)
  })
_sym_db.RegisterMessage(SpaceDeletionResponse)

SpaceListRequest = _reflection.GeneratedProtocolMessageType('SpaceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPACELISTREQUEST,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceListRequest)
  })
_sym_db.RegisterMessage(SpaceListRequest)

SpaceListResponse = _reflection.GeneratedProtocolMessageType('SpaceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPACELISTRESPONSE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceListResponse)
  })
_sym_db.RegisterMessage(SpaceListResponse)

SpaceUpdateRequest = _reflection.GeneratedProtocolMessageType('SpaceUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SPACEUPDATEREQUEST,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceUpdateRequest)
  })
_sym_db.RegisterMessage(SpaceUpdateRequest)

SpaceUpdateResponse = _reflection.GeneratedProtocolMessageType('SpaceUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SPACEUPDATERESPONSE,
  '__module__' : 'space_pb2'
  # @@protoc_insertion_point(class_scope:space.SpaceUpdateResponse)
  })
_sym_db.RegisterMessage(SpaceUpdateResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/jupyter-naas/naas-models/go/space'
  _CONTAINER_ENVENTRY._options = None
  _CONTAINER_ENVENTRY._serialized_options = b'8\001'
  _CONTAINER.fields_by_name['name']._options = None
  _CONTAINER.fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _CONTAINER.fields_by_name['image']._options = None
  _CONTAINER.fields_by_name['image']._serialized_options = b'\372B3r1\020\0012*^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$\320\001\000'
  _CONTAINER.fields_by_name['port']._options = None
  _CONTAINER.fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _CONTAINER.fields_by_name['cpu']._options = None
  _CONTAINER.fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[0-9]+(.[0-9]+)?[m]?$\320\001\000'
  _CONTAINER.fields_by_name['memory']._options = None
  _CONTAINER.fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[0-9]+(Mi|Gi|Ki)$\320\001\000'
  _CONTAINERUPDATE_ENVENTRY._options = None
  _CONTAINERUPDATE_ENVENTRY._serialized_options = b'8\001'
  _CONTAINERUPDATE.fields_by_name['name']._options = None
  _CONTAINERUPDATE.fields_by_name['name']._serialized_options = b'\372B\031r\027\020\001\030?2\021^([A-Za-z0-9-]+)$'
  _CONTAINERUPDATE.fields_by_name['image']._options = None
  _CONTAINERUPDATE.fields_by_name['image']._serialized_options = b'\372B3r1\020\0012*^[a-zA-Z0-9\\.\\/-]+([:][a-zA-Z0-9\\.\\/-]*)?$\320\001\000'
  _CONTAINERUPDATE.fields_by_name['port']._options = None
  _CONTAINERUPDATE.fields_by_name['port']._serialized_options = b'\372B\010\"\006\030\377\377\003(\000'
  _CONTAINERUPDATE.fields_by_name['cpu']._options = None
  _CONTAINERUPDATE.fields_by_name['cpu']._serialized_options = b'\372B\035r\0332\026^[0-9]+(.[0-9]+)?[m]?$\320\001\000'
  _CONTAINERUPDATE.fields_by_name['memory']._options = None
  _CONTAINERUPDATE.fields_by_name['memory']._serialized_options = b'\372B\031r\0272\022^[0-9]+(Mi|Gi|Ki)$\320\001\000'
  _SPACE.fields_by_name['name']._options = None
  _SPACE.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _SPACE.fields_by_name['user_id']._options = None
  _SPACE.fields_by_name['user_id']._serialized_options = b'\372B\005r\003\260\001\001'
  _SPACE.fields_by_name['id']._options = None
  _SPACE.fields_by_name['id']._serialized_options = b'\372B\005r\003\260\001\001'
  _SPACE.fields_by_name['domain']._options = None
  _SPACE.fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _SPACE.fields_by_name['containers']._options = None
  _SPACE.fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SPACEUPDATE.fields_by_name['domain']._options = None
  _SPACEUPDATE.fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _SPACEUPDATE.fields_by_name['containers']._options = None
  _SPACEUPDATE.fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SPACECREATIONREQUEST.fields_by_name['name']._options = None
  _SPACECREATIONREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _SPACECREATIONREQUEST.fields_by_name['domain']._options = None
  _SPACECREATIONREQUEST.fields_by_name['domain']._serialized_options = b'\372B\005r\003\220\001\001'
  _SPACECREATIONREQUEST.fields_by_name['containers']._options = None
  _SPACECREATIONREQUEST.fields_by_name['containers']._serialized_options = b'\372B\005\222\001\002\010\001'
  _SPACEGETREQUEST.fields_by_name['name']._options = None
  _SPACEGETREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _SPACEDELETIONREQUEST.fields_by_name['name']._options = None
  _SPACEDELETIONREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _SPACEUPDATEREQUEST.fields_by_name['name']._options = None
  _SPACEUPDATEREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _SPACEERROR._serialized_start=2418
  _SPACEERROR._serialized_end=2560
  _CONTAINER._serialized_start=39
  _CONTAINER._serialized_end=441
  _CONTAINER_ENVENTRY._serialized_start=352
  _CONTAINER_ENVENTRY._serialized_end=394
  _CONTAINERUPDATE._serialized_start=444
  _CONTAINERUPDATE._serialized_end=858
  _CONTAINERUPDATE_ENVENTRY._serialized_start=352
  _CONTAINERUPDATE_ENVENTRY._serialized_end=394
  _SPACE._serialized_start=861
  _SPACE._serialized_end=1109
  _SPACEUPDATE._serialized_start=1111
  _SPACEUPDATE._serialized_end=1220
  _SPACERESPONSEERROR._serialized_start=1223
  _SPACERESPONSEERROR._serialized_end=1388
  _SPACECREATIONREQUEST._serialized_start=1391
  _SPACECREATIONREQUEST._serialized_end=1576
  _SPACECREATIONRESPONSE._serialized_start=1578
  _SPACECREATIONRESPONSE._serialized_end=1677
  _SPACEGETREQUEST._serialized_start=1679
  _SPACEGETREQUEST._serialized_end=1769
  _SPACEGETRESPONSE._serialized_start=1771
  _SPACEGETRESPONSE._serialized_end=1865
  _SPACEDELETIONREQUEST._serialized_start=1867
  _SPACEDELETIONREQUEST._serialized_end=1962
  _SPACEDELETIONRESPONSE._serialized_start=1964
  _SPACEDELETIONRESPONSE._serialized_end=2019
  _SPACELISTREQUEST._serialized_start=2021
  _SPACELISTREQUEST._serialized_end=2119
  _SPACELISTRESPONSE._serialized_start=2121
  _SPACELISTRESPONSE._serialized_end=2170
  _SPACEUPDATEREQUEST._serialized_start=2173
  _SPACEUPDATEREQUEST._serialized_end=2316
  _SPACEUPDATERESPONSE._serialized_start=2318
  _SPACEUPDATERESPONSE._serialized_end=2415
# @@protoc_insertion_point(module_scope)



# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from google.protobuf.message import Message  # type: ignore
from pydantic import BaseModel
from pydantic.fields import FieldInfo
import typing





class FieldMask(BaseModel):

    paths: typing.List[str] = FieldInfo(default_factory=list, min_items=1) 





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: secret.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csecret.proto\x12\x07secrets\x1a\x0evalidate.proto\"B\n\x06Secret\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x08\n\x06_value\"k\n\x13SecretResponseError\x12(\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x14.secrets.SecretErrorH\x00\x88\x01\x01\x12\x14\n\x07message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\n\n\x08_message\"F\n\x13SecretCreateRequest\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x42\t\n\x07_secret\"R\n\x14SecretCreateResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\".\n\x10SecretGetRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x80\x01\n\x11SecretGetResponse\x12$\n\x06secret\x18\x01 \x01(\x0b\x32\x0f.secrets.SecretH\x00\x88\x01\x01\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x01\x88\x01\x01\x42\t\n\x07_secretB\x08\n\x06_error\"1\n\x13SecretDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x14SecretDeleteResponse\x12\x30\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"c\n\x11SecretListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"r\n\x12SecretListResponse\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\x12\x30\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1c.secrets.SecretResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\";\n\x17SecretBulkCreateRequest\x12 \n\x07secrets\x18\x01 \x03(\x0b\x32\x0f.secrets.Secret\"G\n\x18SecretBulkCreateResponse\x12+\n\x05\x65rror\x18\x01 \x03(\x0b\x32\x1c.secrets.SecretResponseError*s\n\x0bSecretError\x12\x13\n\x0fSECRET_NO_ERROR\x10\x00\x12\x19\n\x15SECRET_ALREADY_EXISTS\x10\x01\x12\x14\n\x10SECRET_NOT_FOUND\x10\x02\x12\x1e\n\x1aSECRET_MARKED_FOR_DELETION\x10\x03\x42\x30Z.github.com/jupyter-naas/naas-models/go/secretsb\x06proto3')

_SECRETERROR = DESCRIPTOR.enum_types_by_name['SecretError']
SecretError = enum_type_wrapper.EnumTypeWrapper(_SECRETERROR)
SECRET_NO_ERROR = 0
SECRET_ALREADY_EXISTS = 1
SECRET_NOT_FOUND = 2
SECRET_MARKED_FOR_DELETION = 3


_SECRET = DESCRIPTOR.message_types_by_name['Secret']
_SECRETRESPONSEERROR = DESCRIPTOR.message_types_by_name['SecretResponseError']
_SECRETCREATEREQUEST = DESCRIPTOR.message_types_by_name['SecretCreateRequest']
_SECRETCREATERESPONSE = DESCRIPTOR.message_types_by_name['SecretCreateResponse']
_SECRETGETREQUEST = DESCRIPTOR.message_types_by_name['SecretGetRequest']
_SECRETGETRESPONSE = DESCRIPTOR.message_types_by_name['SecretGetResponse']
_SECRETDELETEREQUEST = DESCRIPTOR.message_types_by_name['SecretDeleteRequest']
_SECRETDELETERESPONSE = DESCRIPTOR.message_types_by_name['SecretDeleteResponse']
_SECRETLISTREQUEST = DESCRIPTOR.message_types_by_name['SecretListRequest']
_SECRETLISTRESPONSE = DESCRIPTOR.message_types_by_name['SecretListResponse']
_SECRETBULKCREATEREQUEST = DESCRIPTOR.message_types_by_name['SecretBulkCreateRequest']
_SECRETBULKCREATERESPONSE = DESCRIPTOR.message_types_by_name['SecretBulkCreateResponse']
Secret = _reflection.GeneratedProtocolMessageType('Secret', (_message.Message,), {
  'DESCRIPTOR' : _SECRET,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.Secret)
  })
_sym_db.RegisterMessage(Secret)

SecretResponseError = _reflection.GeneratedProtocolMessageType('SecretResponseError', (_message.Message,), {
  'DESCRIPTOR' : _SECRETRESPONSEERROR,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretResponseError)
  })
_sym_db.RegisterMessage(SecretResponseError)

SecretCreateRequest = _reflection.GeneratedProtocolMessageType('SecretCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETCREATEREQUEST,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretCreateRequest)
  })
_sym_db.RegisterMessage(SecretCreateRequest)

SecretCreateResponse = _reflection.GeneratedProtocolMessageType('SecretCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETCREATERESPONSE,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretCreateResponse)
  })
_sym_db.RegisterMessage(SecretCreateResponse)

SecretGetRequest = _reflection.GeneratedProtocolMessageType('SecretGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGETREQUEST,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretGetRequest)
  })
_sym_db.RegisterMessage(SecretGetRequest)

SecretGetResponse = _reflection.GeneratedProtocolMessageType('SecretGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETGETRESPONSE,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretGetResponse)
  })
_sym_db.RegisterMessage(SecretGetResponse)

SecretDeleteRequest = _reflection.GeneratedProtocolMessageType('SecretDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETDELETEREQUEST,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretDeleteRequest)
  })
_sym_db.RegisterMessage(SecretDeleteRequest)

SecretDeleteResponse = _reflection.GeneratedProtocolMessageType('SecretDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETDELETERESPONSE,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretDeleteResponse)
  })
_sym_db.RegisterMessage(SecretDeleteResponse)

SecretListRequest = _reflection.GeneratedProtocolMessageType('SecretListRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETLISTREQUEST,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretListRequest)
  })
_sym_db.RegisterMessage(SecretListRequest)

SecretListResponse = _reflection.GeneratedProtocolMessageType('SecretListResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETLISTRESPONSE,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretListResponse)
  })
_sym_db.RegisterMessage(SecretListResponse)

SecretBulkCreateRequest = _reflection.GeneratedProtocolMessageType('SecretBulkCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _SECRETBULKCREATEREQUEST,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretBulkCreateRequest)
  })
_sym_db.RegisterMessage(SecretBulkCreateRequest)

SecretBulkCreateResponse = _reflection.GeneratedProtocolMessageType('SecretBulkCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _SECRETBULKCREATERESPONSE,
  '__module__' : 'secret_pb2'
  # @@protoc_insertion_point(class_scope:secrets.SecretBulkCreateResponse)
  })
_sym_db.RegisterMessage(SecretBulkCreateResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z.github.com/jupyter-naas/naas-models/go/secrets'
  _SECRETERROR._serialized_start=1039
  _SECRETERROR._serialized_end=1154
  _SECRET._serialized_start=41
  _SECRET._serialized_end=107
  _SECRETRESPONSEERROR._serialized_start=109
  _SECRETRESPONSEERROR._serialized_end=216
  _SECRETCREATEREQUEST._serialized_start=218
  _SECRETCREATEREQUEST._serialized_end=288
  _SECRETCREATERESPONSE._serialized_start=290
  _SECRETCREATERESPONSE._serialized_end=372
  _SECRETGETREQUEST._serialized_start=374
  _SECRETGETREQUEST._serialized_end=420
  _SECRETGETRESPONSE._serialized_start=423
  _SECRETGETRESPONSE._serialized_end=551
  _SECRETDELETEREQUEST._serialized_start=553
  _SECRETDELETEREQUEST._serialized_end=602
  _SECRETDELETERESPONSE._serialized_start=604
  _SECRETDELETERESPONSE._serialized_end=686
  _SECRETLISTREQUEST._serialized_start=688
  _SECRETLISTREQUEST._serialized_end=787
  _SECRETLISTRESPONSE._serialized_start=789
  _SECRETLISTRESPONSE._serialized_end=903
  _SECRETBULKCREATEREQUEST._serialized_start=905
  _SECRETBULKCREATEREQUEST._serialized_end=964
  _SECRETBULKCREATERESPONSE._serialized_start=966
  _SECRETBULKCREATERESPONSE._serialized_end=1037
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: registry.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0eregistry.proto\x12\x08registry\x1a\x0evalidate.proto\"\x8f\x01\n\x08Registry\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x10\n\x03uri\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\n\n\x08_user_idB\x06\n\x04_uri\"]\n\x13RegistryCredentials\x12\x15\n\x08username\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08password\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_usernameB\x0b\n\t_password\"b\n\x17RegistryCreationRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"R\n\x18RegistryCreationResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x84\x01\n\x1dRegistryCreationResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x13RegistryListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\">\n\x14RegistryListResponse\x12&\n\nregistries\x18\x01 \x03(\x0b\x32\x12.registry.Registry\"]\n\x12RegistryGetRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"M\n\x13RegistryGetResponse\x12)\n\x08registry\x18\x01 \x01(\x0b\x32\x12.registry.RegistryH\x00\x88\x01\x01\x42\x0b\n\t_registry\"\x7f\n\x18RegistryGetResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"3\n\x15RegistryDeleteRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"\x82\x01\n\x1bRegistryDeleteResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message\"e\n\x1aRegistryCredentialsRequest\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x42\x07\n\x05_name\"\xaf\x01\n\x1bRegistryCredentialsResponse\x12>\n\x04name\x18\x01 \x01(\tB+\xfa\x42(r&\x10\x01\x18?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$H\x00\x88\x01\x01\x12\x37\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x1d.registry.RegistryCredentialsH\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0e\n\x0c_credentials\"\x87\x01\n RegistryCredentialsResponseError\x12+\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x17.registry.RegistryErrorH\x00\x88\x01\x01\x12\x1a\n\rerror_message\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x10\n\x0e_error_message*X\n\rRegistryError\x12\x1b\n\x17REGISTRY_ALREADY_EXISTS\x10\x00\x12\x16\n\x12REGISTRY_NOT_FOUND\x10\x01\x12\x12\n\x0eNOT_AUTHORIZED\x10\x02\x42\x31Z/github.com/jupyter-naas/naas-models/go/registryb\x06proto3')

_REGISTRYERROR = DESCRIPTOR.enum_types_by_name['RegistryError']
RegistryError = enum_type_wrapper.EnumTypeWrapper(_REGISTRYERROR)
REGISTRY_ALREADY_EXISTS = 0
REGISTRY_NOT_FOUND = 1
NOT_AUTHORIZED = 2


_REGISTRY = DESCRIPTOR.message_types_by_name['Registry']
_REGISTRYCREDENTIALS = DESCRIPTOR.message_types_by_name['RegistryCredentials']
_REGISTRYCREATIONREQUEST = DESCRIPTOR.message_types_by_name['RegistryCreationRequest']
_REGISTRYCREATIONRESPONSE = DESCRIPTOR.message_types_by_name['RegistryCreationResponse']
_REGISTRYCREATIONRESPONSEERROR = DESCRIPTOR.message_types_by_name['RegistryCreationResponseError']
_REGISTRYLISTREQUEST = DESCRIPTOR.message_types_by_name['RegistryListRequest']
_REGISTRYLISTRESPONSE = DESCRIPTOR.message_types_by_name['RegistryListResponse']
_REGISTRYGETREQUEST = DESCRIPTOR.message_types_by_name['RegistryGetRequest']
_REGISTRYGETRESPONSE = DESCRIPTOR.message_types_by_name['RegistryGetResponse']
_REGISTRYGETRESPONSEERROR = DESCRIPTOR.message_types_by_name['RegistryGetResponseError']
_REGISTRYDELETEREQUEST = DESCRIPTOR.message_types_by_name['RegistryDeleteRequest']
_REGISTRYDELETERESPONSEERROR = DESCRIPTOR.message_types_by_name['RegistryDeleteResponseError']
_REGISTRYCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['RegistryCredentialsRequest']
_REGISTRYCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['RegistryCredentialsResponse']
_REGISTRYCREDENTIALSRESPONSEERROR = DESCRIPTOR.message_types_by_name['RegistryCredentialsResponseError']
Registry = _reflection.GeneratedProtocolMessageType('Registry', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRY,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.Registry)
  })
_sym_db.RegisterMessage(Registry)

RegistryCredentials = _reflection.GeneratedProtocolMessageType('RegistryCredentials', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREDENTIALS,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCredentials)
  })
_sym_db.RegisterMessage(RegistryCredentials)

RegistryCreationRequest = _reflection.GeneratedProtocolMessageType('RegistryCreationRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREATIONREQUEST,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCreationRequest)
  })
_sym_db.RegisterMessage(RegistryCreationRequest)

RegistryCreationResponse = _reflection.GeneratedProtocolMessageType('RegistryCreationResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREATIONRESPONSE,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCreationResponse)
  })
_sym_db.RegisterMessage(RegistryCreationResponse)

RegistryCreationResponseError = _reflection.GeneratedProtocolMessageType('RegistryCreationResponseError', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREATIONRESPONSEERROR,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCreationResponseError)
  })
_sym_db.RegisterMessage(RegistryCreationResponseError)

RegistryListRequest = _reflection.GeneratedProtocolMessageType('RegistryListRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYLISTREQUEST,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryListRequest)
  })
_sym_db.RegisterMessage(RegistryListRequest)

RegistryListResponse = _reflection.GeneratedProtocolMessageType('RegistryListResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYLISTRESPONSE,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryListResponse)
  })
_sym_db.RegisterMessage(RegistryListResponse)

RegistryGetRequest = _reflection.GeneratedProtocolMessageType('RegistryGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYGETREQUEST,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryGetRequest)
  })
_sym_db.RegisterMessage(RegistryGetRequest)

RegistryGetResponse = _reflection.GeneratedProtocolMessageType('RegistryGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYGETRESPONSE,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryGetResponse)
  })
_sym_db.RegisterMessage(RegistryGetResponse)

RegistryGetResponseError = _reflection.GeneratedProtocolMessageType('RegistryGetResponseError', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYGETRESPONSEERROR,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryGetResponseError)
  })
_sym_db.RegisterMessage(RegistryGetResponseError)

RegistryDeleteRequest = _reflection.GeneratedProtocolMessageType('RegistryDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYDELETEREQUEST,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryDeleteRequest)
  })
_sym_db.RegisterMessage(RegistryDeleteRequest)

RegistryDeleteResponseError = _reflection.GeneratedProtocolMessageType('RegistryDeleteResponseError', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYDELETERESPONSEERROR,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryDeleteResponseError)
  })
_sym_db.RegisterMessage(RegistryDeleteResponseError)

RegistryCredentialsRequest = _reflection.GeneratedProtocolMessageType('RegistryCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREDENTIALSREQUEST,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCredentialsRequest)
  })
_sym_db.RegisterMessage(RegistryCredentialsRequest)

RegistryCredentialsResponse = _reflection.GeneratedProtocolMessageType('RegistryCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREDENTIALSRESPONSE,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCredentialsResponse)
  })
_sym_db.RegisterMessage(RegistryCredentialsResponse)

RegistryCredentialsResponseError = _reflection.GeneratedProtocolMessageType('RegistryCredentialsResponseError', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRYCREDENTIALSRESPONSEERROR,
  '__module__' : 'registry_pb2'
  # @@protoc_insertion_point(class_scope:registry.RegistryCredentialsResponseError)
  })
_sym_db.RegisterMessage(RegistryCredentialsResponseError)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/jupyter-naas/naas-models/go/registry'
  _REGISTRY.fields_by_name['name']._options = None
  _REGISTRY.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _REGISTRYCREATIONREQUEST.fields_by_name['name']._options = None
  _REGISTRYCREATIONREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _REGISTRYGETREQUEST.fields_by_name['name']._options = None
  _REGISTRYGETREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _REGISTRYCREDENTIALSREQUEST.fields_by_name['name']._options = None
  _REGISTRYCREDENTIALSREQUEST.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _REGISTRYCREDENTIALSRESPONSE.fields_by_name['name']._options = None
  _REGISTRYCREDENTIALSRESPONSE.fields_by_name['name']._serialized_options = b'\372B(r&\020\001\030?2 ^([A-Za-z0-9]+(-[A-Za-z0-9]+)+)$'
  _REGISTRYERROR._serialized_start=1679
  _REGISTRYERROR._serialized_end=1767
  _REGISTRY._serialized_start=45
  _REGISTRY._serialized_end=188
  _REGISTRYCREDENTIALS._serialized_start=190
  _REGISTRYCREDENTIALS._serialized_end=283
  _REGISTRYCREATIONREQUEST._serialized_start=285
  _REGISTRYCREATIONREQUEST._serialized_end=383
  _REGISTRYCREATIONRESPONSE._serialized_start=385
  _REGISTRYCREATIONRESPONSE._serialized_end=467
  _REGISTRYCREATIONRESPONSEERROR._serialized_start=470
  _REGISTRYCREATIONRESPONSEERROR._serialized_end=602
  _REGISTRYLISTREQUEST._serialized_start=604
  _REGISTRYLISTREQUEST._serialized_end=705
  _REGISTRYLISTRESPONSE._serialized_start=707
  _REGISTRYLISTRESPONSE._serialized_end=769
  _REGISTRYGETREQUEST._serialized_start=771
  _REGISTRYGETREQUEST._serialized_end=864
  _REGISTRYGETRESPONSE._serialized_start=866
  _REGISTRYGETRESPONSE._serialized_end=943
  _REGISTRYGETRESPONSEERROR._serialized_start=945
  _REGISTRYGETRESPONSEERROR._serialized_end=1072
  _REGISTRYDELETEREQUEST._serialized_start=1074
  _REGISTRYDELETEREQUEST._serialized_end=1125
  _REGISTRYDELETERESPONSEERROR._serialized_start=1128
  _REGISTRYDELETERESPONSEERROR._serialized_end=1258
  _REGISTRYCREDENTIALSREQUEST._serialized_start=1260
  _REGISTRYCREDENTIALSREQUEST._serialized_end=1361
  _REGISTRYCREDENTIALSRESPONSE._serialized_start=1364
  _REGISTRYCREDENTIALSRESPONSE._serialized_end=1539
  _REGISTRYCREDENTIALSRESPONSEERROR._serialized_start=1542
  _REGISTRYCREDENTIALSRESPONSEERROR._serialized_end=1677
# @@protoc_insertion_point(module_scope)
